@@ -52,8 +52,8 @@ public:
   virtual void addToKeypointList(KeypointList &) const;
   virtual void extractPositionFromKeypointList(KeypointList &);
 
-  static AbstractParameter * createFromText(const char * text, int & length, QString & error, QObject * parent);
-  virtual bool initFromText(const char * text, int & textLength) = 0;
+  static AbstractParameter * createFromText(const QString & filterName, const char * text, int & length, QString & error, QObject * parent);
+  virtual bool initFromText(const QString & filterName, const char * text, int & textLength) = 0;
 
   enum class VisibilityState
   {
