@@ -137,14 +137,14 @@ void FloatParameter::reset()
   connectSliderSpinBox();
 }
 
-bool FloatParameter::initFromText(const char * text, int & textLength)
+bool FloatParameter::initFromText(const QString & filterName, const char * text, int & textLength)
 {
   textLength = 0;
   QList<QString> list = parseText("float", text, textLength);
   if (list.isEmpty()) {
     return false;
   }
-  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0]));
+  _name = HtmlTranslator::html2txt(FilterTextTranslator::translate(list[0], filterName));
   QList<QString> values = list[1].split(QChar(','));
   if (values.size() != 3) {
     return false;
@@ -161,7 +161,7 @@ void FloatParameter::timerEvent(QTimerEvent * event)
 {
   killTimer(event->timerId());
   _timerId = 0;
-  if (not _spinBox->unfinishedKeyboardEditing()) {
+  if (!_spinBox->unfinishedKeyboardEditing()) {
     notifyIfRelevant();
   }
 }
