@@ -30,6 +30,9 @@
 class QByteArray;
 class QBuffer;
 
+namespace GmicQt
+{
+
 class FiltersModelReader {
 public:
   FiltersModelReader(FiltersModel & model);
@@ -39,6 +42,9 @@ private:
   FiltersModel & _model;
   static QString readBufferLine(QBuffer &);
   static bool textIsPrecededBySpacesInSomeLineOfArray(const QByteArray & text, const QByteArray & array);
+  static InputMode symbolToInputMode(const QString & str);
 };
 
+} // namespace GmicQt
+
 #endif // GMIC_QT_FILTERSMODELREADER_H
