@@ -270,7 +270,7 @@ void FiltersPresenter::selectFilterFromHash(QString hash, bool notify)
       hashExists = false;
     }
   }
-  if (not hashExists) {
+  if (!hashExists) {
     hash.clear();
   }
   setCurrentFilter(hash);
@@ -568,12 +568,12 @@ void FiltersPresenter::onTagToggled(int)
 
 bool FiltersPresenter::danglingFaveIsSelected() const
 {
-  if (not _filtersView || not _filtersView->aFaveIsSelected()) {
+  if (!_filtersView || !_filtersView->aFaveIsSelected()) {
     return false;
   }
   QString hash = _filtersView->selectedFilterHash();
   if (_favesModel.contains(hash)) {
-    return not _filtersModel.contains(_favesModel.getFaveFromHash(hash).originalHash());
+    return !_filtersModel.contains(_favesModel.getFaveFromHash(hash).originalHash());
   }
   return false;
 }
