@@ -32,6 +32,7 @@
 #include <QStandardItem>
 #include <QStringList>
 #include "Common.h"
+#include "FilterSelector/FilterTagMap.h"
 #include "FilterSelector/FiltersView/FilterTreeFolder.h"
 #include "FilterSelector/FiltersView/FilterTreeItem.h"
 #include "FilterSelector/FiltersView/FilterTreeItemDelegate.h"
@@ -63,19 +64,8 @@ FiltersView::FiltersView(QWidget * parent) : QWidget(parent), ui(new Ui::Filters
 
   ui->treeView->setContextMenuPolicy(Qt::CustomContextMenu);
   connect(ui->treeView, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(onCustomContextMenu(QPoint)));
-  _faveContextMenu = new QMenu(this);
-  QAction * action;
-  action = _faveContextMenu->addAction(tr("Rename fave"));
-  connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuRenameFave()));
-  action = _faveContextMenu->addAction(tr("Remove fave"));
-  connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuRemoveFave()));
-  action = _faveContextMenu->addAction(tr("Clone fave"));
-  connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuAddFave()));
-
-  _filterContextMenu = new QMenu(this);
-  action = _filterContextMenu->addAction(tr("Add fave"));
-  connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuAddFave()));
-
+  _faveContextMenu = nullptr;
+  _filterContextMenu = nullptr;
   ui->treeView->installEventFilter(this);
 }
 
@@ -120,9 +110,13 @@ void FiltersView::createFolder(const QList<QString> & path)
 void FiltersView::addFilter(const QString & text, const QString & hash, const QList<QString> & path, bool warning)
 {
   const bool filterIsVisible = FiltersVisibilityMap::filterIsVisible(hash);
+  TagColorSet tagColors = FiltersTagMap::filterTags(hash);
   if (!_isInSelectionMode && !filterIsVisible) {
     return;
   }
+  if (!_visibleTagColors.isEmpty() && (tagColors & _visibleTagColors).isEmpty()) {
+    return;
+  }
   QStandardItem * folder = getFolderFromPath(path);
   if (!folder) {
     folder = createFolder(_model.invisibleRootItem(), path);
@@ -130,6 +124,7 @@ void FiltersView::addFilter(const QString & text, const QString & hash, const QL
   auto item = new FilterTreeItem(text);
   item->setHash(hash);
   item->setWarningFlag(warning);
+  item->setTags(tagColors);
   if (_isInSelectionMode) {
     addStandardItemWithCheckbox(folder, item);
     item->setVisibility(filterIsVisible);
@@ -141,9 +136,13 @@ void FiltersView::addFilter(const QString & text, const QString & hash, const QL
 void FiltersView::addFave(const QString & text, const QString & hash)
 {
   const bool faveIsVisible = FiltersVisibilityMap::filterIsVisible(hash);
+  TagColorSet tagColors = FiltersTagMap::filterTags(hash);
   if (!_isInSelectionMode && !faveIsVisible) {
     return;
   }
+  if (!_visibleTagColors.isEmpty() && (tagColors & _visibleTagColors).isEmpty()) {
+    return;
+  }
   if (!_faveFolder) {
     createFaveFolder();
   }
@@ -151,6 +150,7 @@ void FiltersView::addFave(const QString & text, const QString & hash)
   item->setHash(hash);
   item->setWarningFlag(false);
   item->setFaveFlag(true);
+  item->setTags(tagColors);
   if (_isInSelectionMode) {
     addStandardItemWithCheckbox(_faveFolder, item);
     item->setVisibility(faveIsVisible);
@@ -293,6 +293,7 @@ void FiltersView::restoreExpandedFolders()
 void FiltersView::loadSettings(const QSettings &)
 {
   FiltersVisibilityMap::load();
+  FiltersTagMap::load();
 }
 
 void FiltersView::saveSettings(QSettings & settings)
@@ -300,9 +301,11 @@ void FiltersView::saveSettings(QSettings & settings)
   if (_isInSelectionMode) {
     saveFiltersVisibility(_model.invisibleRootItem());
   }
+  saveFiltersTags(_model.invisibleRootItem());
   preserveExpandedFolders();
   settings.setValue("Config/ExpandedFolders", QStringList(_expandedFolderPaths));
   FiltersVisibilityMap::save();
+  FiltersTagMap::save();
 }
 
 void FiltersView::enableSelectionMode()
@@ -358,6 +361,16 @@ bool FiltersView::eventFilter(QObject * watched, QEvent * event)
   return QObject::eventFilter(watched, event);
 }
 
+void FiltersView::setVisibleTagColors(const TagColorSet & colors)
+{
+  _visibleTagColors = colors;
+}
+
+TagColorSet FiltersView::visibleTagColors() const
+{
+  return _visibleTagColors;
+}
+
 void FiltersView::expandFolders(const QList<QString> & folderPaths, QStandardItem * folder)
 {
   int rows = folder->rowCount();
@@ -411,8 +424,12 @@ void FiltersView::onCustomContextMenu(const QPoint & point)
   }
   onItemClicked(index);
   if (item->isFave()) {
+    _faveContextMenu->deleteLater();
+    _faveContextMenu = itemContextMenu(MenuType::Fave, item);
     _faveContextMenu->exec(ui->treeView->mapToGlobal(point));
   } else {
+    _filterContextMenu->deleteLater();
+    _filterContextMenu = itemContextMenu(MenuType::Filter, item);
     _filterContextMenu->exec(ui->treeView->mapToGlobal(point));
   }
 }
@@ -628,6 +645,91 @@ void FiltersView::saveFiltersVisibility(QStandardItem * item)
   }
 }
 
+void FiltersView::saveFiltersTags(QStandardItem * item)
+{
+  if (!item) {
+    return;
+  }
+  auto filterItem = dynamic_cast<FilterTreeItem *>(item);
+  if (filterItem) {
+    FiltersTagMap::setFilterTags(filterItem->hash(), filterItem->tags());
+    return;
+  }
+  int rows = item->rowCount();
+  for (int row = 0; row < rows; ++row) {
+    saveFiltersTags(item->child(row));
+  }
+}
+
+QMenu * FiltersView::itemContextMenu(MenuType type, FilterTreeItem * item)
+{
+  QMenu * menu = new QMenu(this);
+  QAction * action;
+  switch (type) {
+  case MenuType::Fave:
+    action = menu->addAction(tr("Rename Fave"));
+    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuRenameFave()));
+    action = menu->addAction(tr("Remove Fave"));
+    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuRemoveFave()));
+    action = menu->addAction(tr("Clone Fave"));
+    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuAddFave()));
+    break;
+  case MenuType::Filter:
+    action = menu->addAction(tr("Add Fave"));
+    connect(action, SIGNAL(triggered(bool)), this, SLOT(onContextMenuAddFave()));
+    break;
+  }
+  TagColorSet tags = item->tags();
+  menu->addSeparator();
+  for (TagColor color : TagColorSet::ActualColors) {
+    QAction * action = TagAssets::action(menu,  //
+                                         color, //
+                                         tags.contains(color) ? TagAssets::IconMark::Check : TagAssets::IconMark::None);
+    connect(action, &QAction::triggered, [this, item, color]() { //
+      toggleItemTag(item, color);
+      emit tagToggled(int(color));
+    });
+    menu->addAction(action);
+  }
+  menu->addSeparator();
+  int tagCount[int(TagColor::Count)];
+  TagColorSet existingColors = FiltersTagMap::usedColors(tagCount);
+  QMenu * removeMenu = menu->addMenu(tr("Remove All"));
+  if (existingColors.isEmpty()) {
+    removeMenu->setEnabled(false);
+  } else {
+    for (TagColor color : existingColors) {
+      int iColor = int(color);
+      removeMenu->addAction(action = TagAssets::action(removeMenu, color, TagAssets::IconMark::None));
+      action->setText(QString(tr("%1 (%2 %3)")).arg(TagAssets::colorName(color)).arg(tagCount[iColor]).arg((tagCount[iColor] != 1) ? tr("Filters") : tr("Filter")));
+      connect(action, &QAction::triggered, [this, color, iColor]() {
+        FiltersTagMap::removeAllTags(color);
+        emit tagToggled(iColor);
+      });
+    }
+  }
+  return menu;
+}
+
+void FiltersView::toggleItemTag(FilterTreeItem * item, TagColor color)
+{
+  item->toggleTag(color);
+  if (!_visibleTagColors.contains(color)) {
+    return;
+  }
+  QStandardItem * folder = item->parent();
+  folder->removeRow(item->row());
+  while (folder && (folder != _model.invisibleRootItem()) && (folder->rowCount() == 0)) {
+    QStandardItem * folderParent = folder->parent();
+    if (!folderParent) {
+      folderParent = _model.invisibleRootItem();
+    }
+    const int row = folder->row();
+    folderParent->removeRow(row);
+    folder = folderParent;
+  }
+}
+
 FilterTreeItem * FiltersView::findFave(const QString & hash)
 {
   const int count = _faveFolder ? _faveFolder->rowCount() : 0;
