@@ -36,14 +36,17 @@
 #include "FilterSyncRunner.h"
 #include "FilterThread.h"
 #include "Globals.h"
-#include "Host/host.h"
-#include "ImageConverter.h"
+#include "Host/GmicQtHost.h"
 #include "ImageTools.h"
 #include "LayersExtentProxy.h"
 #include "Logger.h"
+#include "Misc.h"
 #include "OverrideCursor.h"
 #include "gmic.h"
 
+namespace GmicQt
+{
+
 GmicProcessor::GmicProcessor(QObject * parent) : QObject(parent)
 {
   _filterThread = nullptr;
@@ -53,7 +56,7 @@ GmicProcessor::GmicProcessor(QObject * parent) : QObject(parent)
   connect(&_waitingCursorTimer, SIGNAL(timeout()), this, SLOT(showWaitingCursor()));
   cimg_library::cimg::srand();
   _previewRandomSeed = cimg_library::cimg::_rand();
-  _lastAppliedCommandInOutState = GmicQt::InputOutputState::Unspecified;
+  _lastAppliedCommandInOutState = InputOutputState::Unspecified;
   _filterExecutionTime.start();
   _completeFullImageProcessingCount = 0;
 }
@@ -74,25 +77,26 @@ void GmicProcessor::execute()
   gmic_list<char> imageNames;
   FilterContext::VisibleRect & rect = _filterContext.visibleRect;
   _gmicImages->assign();
-  if ((_filterContext.requestType == FilterContext::PreviewProcessing) || (_filterContext.requestType == FilterContext::SynchronousPreviewProcessing)) {
+  if ((_filterContext.requestType == FilterContext::RequestType::Preview) || //
+      (_filterContext.requestType == FilterContext::RequestType::SynchronousPreview)) {
     CroppedImageListProxy::get(*_gmicImages, imageNames, rect.x, rect.y, rect.w, rect.h, _filterContext.inputOutputState.inputMode, _filterContext.zoomFactor);
     updateImageNames(imageNames);
   } else {
     CroppedImageListProxy::get(*_gmicImages, imageNames, rect.x, rect.y, rect.w, rect.h, _filterContext.inputOutputState.inputMode, 1.0);
   }
   _waitingCursorTimer.start(WAITING_CURSOR_DELAY);
-  const GmicQt::InputOutputState & io = _filterContext.inputOutputState;
-  QString env = QString("_input_layers=%1").arg(io.inputMode);
-  env += QString(" _output_mode=%1").arg(io.outputMode);
-  env += QString(" _output_messages=%1").arg(_filterContext.outputMessageMode);
-  env += QString(" _preview_mode=%1").arg(io.previewMode);
-  if ((_filterContext.requestType == FilterContext::PreviewProcessing) || (_filterContext.requestType == FilterContext::SynchronousPreviewProcessing)) {
+  const InputOutputState & io = _filterContext.inputOutputState;
+  QString env = QString("_input_layers=%1").arg(static_cast<int>(io.inputMode));
+  env += QString(" _output_mode=%1").arg(static_cast<int>(io.outputMode));
+  env += QString(" _output_messages=%1").arg(static_cast<int>(_filterContext.outputMessageMode));
+  if ((_filterContext.requestType == FilterContext::RequestType::Preview) || //
+      (_filterContext.requestType == FilterContext::RequestType::SynchronousPreview)) {
     env += QString(" _preview_width=%1").arg(_filterContext.previewWidth);
     env += QString(" _preview_height=%1").arg(_filterContext.previewHeight);
     env += QString(" _preview_timeout=%1").arg(_filterContext.previewTimeout);
   }
-  if (_filterContext.requestType == FilterContext::SynchronousPreviewProcessing) {
-    FilterSyncRunner runner(this, _filterContext.filterName, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
+  if (_filterContext.requestType == FilterContext::RequestType::SynchronousPreview) {
+    FilterSyncRunner runner(this, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
     runner.swapImages(*_gmicImages);
     runner.setImageNames(imageNames);
     runner.setLogSuffix("preview");
@@ -102,8 +106,8 @@ void GmicProcessor::execute()
     runner.run();
     manageSynchonousRunner(runner);
     recordPreviewFilterExecutionDurationMS((int)_filterExecutionTime.elapsed());
-  } else if (_filterContext.requestType == FilterContext::PreviewProcessing) {
-    _filterThread = new FilterThread(this, _filterContext.filterName, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
+  } else if (_filterContext.requestType == FilterContext::RequestType::Preview) {
+    _filterThread = new FilterThread(this, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
     _filterThread->swapImages(*_gmicImages);
     _filterThread->setImageNames(imageNames);
     _filterThread->setLogSuffix("preview");
@@ -112,13 +116,13 @@ void GmicProcessor::execute()
     _previewRandomSeed = cimg_library::cimg::_rand();
     _filterExecutionTime.restart();
     _filterThread->start();
-  } else if (_filterContext.requestType == FilterContext::FullImageProcessing) {
-    _lastAppliedFilterName = _filterContext.filterName;
+  } else if (_filterContext.requestType == FilterContext::RequestType::FullImage) {
+    _lastAppliedFilterHash = _filterContext.filterHash;
+    _lastAppliedFilterPath = _filterContext.filterFullPath;
     _lastAppliedCommand = _filterContext.filterCommand;
     _lastAppliedCommandArguments = _filterContext.filterArguments;
-    _lastAppliedCommandEnv = env;
     _lastAppliedCommandInOutState = _filterContext.inputOutputState;
-    _filterThread = new FilterThread(this, _filterContext.filterName, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
+    _filterThread = new FilterThread(this, _filterContext.filterCommand, _filterContext.filterArguments, env, _filterContext.outputMessageMode);
     _filterThread->swapImages(*_gmicImages);
     _filterThread->setImageNames(imageNames);
     _filterThread->setLogSuffix("apply");
@@ -130,7 +134,7 @@ void GmicProcessor::execute()
 
 bool GmicProcessor::isProcessingFullImage() const
 {
-  return _filterContext.requestType == FilterContext::FullImageProcessing;
+  return _filterContext.requestType == FilterContext::RequestType::FullImage;
 }
 
 bool GmicProcessor::isProcessing() const
@@ -194,11 +198,6 @@ int GmicProcessor::averagePreviewFilterExecutionDuration() const
   return static_cast<int>(sum / count);
 }
 
-void GmicProcessor::setGmicStatusQuotedParameters(const QString & v)
-{
-  _gmicStatusQuotedParameters = v;
-}
-
 int GmicProcessor::completedFullImageProcessingCount() const
 {
   return _completeFullImageProcessingCount;
@@ -226,16 +225,25 @@ const QStringList & GmicProcessor::gmicStatus() const
 
 void GmicProcessor::saveSettings(QSettings & settings)
 {
-  settings.setValue(QString("LastExecution/host_%1/Command").arg(GmicQt::HostApplicationShortname), _lastAppliedCommand);
-  settings.setValue(QString("LastExecution/host_%1/FilterName").arg(GmicQt::HostApplicationShortname), _lastAppliedFilterName);
-  settings.setValue(QString("LastExecution/host_%1/FilterHash").arg(GmicQt::HostApplicationShortname), _filterContext.filterHash);
-  settings.setValue(QString("LastExecution/host_%1/Arguments").arg(GmicQt::HostApplicationShortname), _lastAppliedCommandArguments);
-  settings.setValue(QString("LastExecution/host_%1/GmicStatus").arg(GmicQt::HostApplicationShortname), _lastAppliedCommandGmicStatus);
-  settings.setValue(QString("LastExecution/host_%1/QuotedParameters").arg(GmicQt::HostApplicationShortname), _gmicStatusQuotedParameters);
-  settings.setValue(QString("LastExecution/host_%1/InputMode").arg(GmicQt::HostApplicationShortname), _lastAppliedCommandInOutState.inputMode);
-  settings.setValue(QString("LastExecution/host_%1/OutputMode").arg(GmicQt::HostApplicationShortname), _lastAppliedCommandInOutState.outputMode);
-  settings.setValue(QString("LastExecution/host_%1/PreviewMode").arg(GmicQt::HostApplicationShortname), _lastAppliedCommandInOutState.previewMode);
-  settings.setValue(QString("LastExecution/host_%1/GmicEnvironment").arg(GmicQt::HostApplicationShortname), _lastAppliedCommandEnv);
+  if (_lastAppliedCommand.isEmpty()) {
+    const QString empty;
+    settings.setValue(QString("LastExecution/host_%1/FilterHash").arg(GmicQtHost::ApplicationShortname), empty);
+    settings.setValue(QString("LastExecution/host_%1/FilterPath").arg(GmicQtHost::ApplicationShortname), empty);
+    settings.setValue(QString("LastExecution/host_%1/Command").arg(GmicQtHost::ApplicationShortname), empty);
+    settings.setValue(QString("LastExecution/host_%1/Arguments").arg(GmicQtHost::ApplicationShortname), empty);
+    settings.setValue(QString("LastExecution/host_%1/GmicStatusString").arg(GmicQtHost::ApplicationShortname), QString());
+    settings.setValue(QString("LastExecution/host_%1/InputMode").arg(GmicQtHost::ApplicationShortname), 0);
+    settings.setValue(QString("LastExecution/host_%1/OutputMode").arg(GmicQtHost::ApplicationShortname), 0);
+  } else {
+    settings.setValue(QString("LastExecution/host_%1/FilterPath").arg(GmicQtHost::ApplicationShortname), _lastAppliedFilterPath);
+    settings.setValue(QString("LastExecution/host_%1/FilterHash").arg(GmicQtHost::ApplicationShortname), _lastAppliedFilterHash);
+    settings.setValue(QString("LastExecution/host_%1/Command").arg(GmicQtHost::ApplicationShortname), _lastAppliedCommand);
+    settings.setValue(QString("LastExecution/host_%1/Arguments").arg(GmicQtHost::ApplicationShortname), _lastAppliedCommandArguments);
+    QString status = flattenGmicParameterList(_lastAppliedCommandGmicStatus, _gmicStatusQuotedParameters);
+    settings.setValue(QString("LastExecution/host_%1/GmicStatusString").arg(GmicQtHost::ApplicationShortname), status);
+    settings.setValue(QString("LastExecution/host_%1/InputMode").arg(GmicQtHost::ApplicationShortname), (int)_lastAppliedCommandInOutState.inputMode);
+    settings.setValue(QString("LastExecution/host_%1/OutputMode").arg(GmicQtHost::ApplicationShortname), (int)_lastAppliedCommandInOutState.outputMode);
+  }
 }
 
 GmicProcessor::~GmicProcessor()
@@ -247,6 +255,11 @@ GmicProcessor::~GmicProcessor()
   }
 }
 
+void GmicProcessor::setGmicStatusQuotedParameters(const QVector<bool> & quotedParameters)
+{
+  _gmicStatusQuotedParameters = quotedParameters;
+}
+
 void GmicProcessor::onPreviewThreadFinished()
 {
   Q_ASSERT_X(_filterThread, __PRETTY_FUNCTION__, "No filter thread");
@@ -268,15 +281,24 @@ void GmicProcessor::onPreviewThreadFinished()
   _parametersVisibilityStates = _filterThread->parametersVisibilityStates();
   _gmicImages->assign();
   _filterThread->swapImages(*_gmicImages);
-  for (unsigned int i = 0; i < _gmicImages->size(); ++i) {
-    gmic_qt_apply_color_profile((*_gmicImages)[i]);
+  unsigned int badSpectrumIndex = 0;
+  bool correctSpectrums = checkImageSpectrumAtMost4(*_gmicImages, badSpectrumIndex);
+  if (correctSpectrums) {
+    for (unsigned int i = 0; i < _gmicImages->size(); ++i) {
+      GmicQtHost::applyColorProfile((*_gmicImages)[i]);
+    }
+    buildPreviewImage(*_gmicImages, *_previewImage);
   }
-  GmicQt::buildPreviewImage(*_gmicImages, *_previewImage, _filterContext.inputOutputState.previewMode, _filterContext.previewWidth, _filterContext.previewHeight);
   _filterThread->deleteLater();
   _filterThread = nullptr;
   hideWaitingCursor();
-  emit previewImageAvailable();
-  recordPreviewFilterExecutionDurationMS((int)_filterExecutionTime.elapsed());
+  if (correctSpectrums) {
+    emit previewImageAvailable();
+    recordPreviewFilterExecutionDurationMS((int)_filterExecutionTime.elapsed());
+  } else {
+    QString message(tr("Image #%1 returned by filter has %2 channels (should be at most 4)"));
+    emit previewCommandFailed(message.arg(badSpectrumIndex).arg((*_gmicImages)[badSpectrumIndex].spectrum()));
+  }
 }
 
 void GmicProcessor::onApplyThreadFinished()
@@ -289,8 +311,9 @@ void GmicProcessor::onApplyThreadFinished()
   _gmicStatus = _filterThread->gmicStatus();
   _parametersVisibilityStates = _filterThread->parametersVisibilityStates();
   hideWaitingCursor();
+
   if (_filterThread->failed()) {
-    _lastAppliedFilterName.clear();
+    _lastAppliedFilterPath.clear();
     _lastAppliedCommand.clear();
     _lastAppliedCommandArguments.clear();
     QString message = _filterThread->errorMessage();
@@ -298,19 +321,31 @@ void GmicProcessor::onApplyThreadFinished()
     _filterThread = nullptr;
     emit fullImageProcessingFailed(message);
   } else {
-    if (GmicQt::HostApplicationName.isEmpty()) {
-      emit aboutToSendImagesToHost();
-    }
     _filterThread->swapImages(*_gmicImages);
-    gmic_qt_output_images(*_gmicImages, _filterThread->imageNames(), _filterContext.inputOutputState.outputMode);
-    _completeFullImageProcessingCount += 1;
-    LayersExtentProxy::clear();
-    CroppedActiveLayerProxy::clear();
-    CroppedImageListProxy::clear();
-    _filterThread->deleteLater();
-    _filterThread = nullptr;
-    _lastAppliedCommandGmicStatus = _gmicStatus; // TODO : save visibility states?
-    emit fullImageProcessingDone();
+    unsigned int badSpectrumIndex = 0;
+    bool correctSpectrums = checkImageSpectrumAtMost4(*_gmicImages, badSpectrumIndex);
+    if (!correctSpectrums) {
+      _lastAppliedFilterPath.clear();
+      _lastAppliedCommand.clear();
+      _lastAppliedCommandArguments.clear();
+      _filterThread->deleteLater();
+      _filterThread = nullptr;
+      QString message(tr("Image #%1 returned by filter has %2 channels\n(should be at most 4)"));
+      emit fullImageProcessingFailed(message.arg(badSpectrumIndex).arg((*_gmicImages)[badSpectrumIndex].spectrum()));
+    } else {
+      if (GmicQtHost::ApplicationName.isEmpty()) {
+        emit aboutToSendImagesToHost();
+      }
+      GmicQtHost::outputImages(*_gmicImages, _filterThread->imageNames(), _filterContext.inputOutputState.outputMode);
+      _completeFullImageProcessingCount += 1;
+      LayersExtentProxy::clear();
+      CroppedActiveLayerProxy::clear();
+      CroppedImageListProxy::clear();
+      _filterThread->deleteLater();
+      _filterThread = nullptr;
+      _lastAppliedCommandGmicStatus = _gmicStatus; // TODO : save visibility states?
+      emit fullImageProcessingDone();
+    }
   }
 }
 
@@ -391,9 +426,9 @@ void GmicProcessor::manageSynchonousRunner(FilterSyncRunner & runner)
   _gmicImages->assign();
   runner.swapImages(*_gmicImages);
   for (unsigned int i = 0; i < _gmicImages->size(); ++i) {
-    gmic_qt_apply_color_profile((*_gmicImages)[i]);
+    GmicQtHost::applyColorProfile((*_gmicImages)[i]);
   }
-  GmicQt::buildPreviewImage(*_gmicImages, *_previewImage, _filterContext.inputOutputState.previewMode, _filterContext.previewWidth, _filterContext.previewHeight);
+  buildPreviewImage(*_gmicImages, *_previewImage);
   hideWaitingCursor();
   emit previewImageAvailable();
 }
@@ -402,3 +437,5 @@ const QList<int> & GmicProcessor::parametersVisibilityStates() const
 {
   return _parametersVisibilityStates;
 }
+
+} // namespace GmicQt
