@@ -48,13 +48,13 @@ Updater::Updater(QObject * parent) : QObject(parent)
 
 Updater * Updater::getInstance()
 {
-  if (!_instance.get()) {
+  if (!_instance) {
     _instance = std::unique_ptr<Updater>(new Updater(nullptr));
   }
   return _instance.get();
 }
 
-Updater::~Updater() {}
+Updater::~Updater() = default;
 
 void Updater::updateSources(bool useNetwork)
 {
@@ -93,8 +93,10 @@ void Updater::updateSources(bool useNetwork)
   // NOTE : For testing purpose
   //  _sources.clear();
   //  _sourceIsStdLib.clear();
-  //  _sources.push_back("http://localhost:2222/update220.gmic");
-  //  _sourceIsStdLib["http://localhost:2222/update220.gmic"] = true;
+  //  //  _sources.push_back("http://localhost:2222/update300.gmic");
+  //  //  _sourceIsStdLib["http://localhost:2222/update300.gmic"] = true;
+  //  _sources.push_back("https://gmic.eu/update271.gmic");
+  //  _sourceIsStdLib["https://gmic.eu/update271.gmic"] = true;
 }
 
 void Updater::startUpdate(int ageLimit, int timeout, bool useNetwork)
@@ -103,7 +105,7 @@ void Updater::startUpdate(int ageLimit, int timeout, bool useNetwork)
   updateSources(useNetwork);
   _errorMessages.clear();
   _networkAccessManager = new QNetworkAccessManager(this);
-  connect(_networkAccessManager, SIGNAL(finished(QNetworkReply *)), this, SLOT(onNetworkReplyFinished(QNetworkReply *)));
+  connect(_networkAccessManager, &QNetworkAccessManager::finished, this, &Updater::onNetworkReplyFinished);
   _someNetworkUpdatesAchieved = false;
   if (useNetwork) {
     QDateTime limit = QDateTime::currentDateTime().addSecs(-3600 * (qint64)ageLimit);
@@ -136,10 +138,10 @@ void Updater::startUpdate(int ageLimit, int timeout, bool useNetwork)
     }
   }
   if (_pendingReplies.isEmpty()) {
-    QTimer::singleShot(0, this, SLOT(onUpdateNotNecessary())); // While GUI is Idle
+    QTimer::singleShot(0, this, &Updater::onUpdateNotNecessary); // While GUI is Idle
     _networkAccessManager->deleteLater();
   } else {
-    QTimer::singleShot(timeout * 1000, this, SLOT(cancelAllPendingDownloads()));
+    QTimer::singleShot(timeout * 1000, this, &Updater::cancelAllPendingDownloads);
   }
   TIMING;
 }
@@ -206,16 +208,11 @@ void Updater::processReply(QNetworkReply * reply)
     return;
   }
   QString filename = localFilename(url);
-  QFile file(filename);
-  if (!file.open(QFile::WriteOnly)) {
-    _errorMessages << QString(tr("Error creating file %1")).arg(filename);
+  if (!safelyWrite(array, filename)) {
+    _errorMessages << QString(tr("Error writing file %1")).arg(filename);
     return;
   }
-  if (file.write(array) != array.size()) {
-    _errorMessages << QString(tr("Error writing file %1")).arg(filename);
-  } else {
-    _someNetworkUpdatesAchieved = true;
-  }
+  _someNetworkUpdatesAchieved = true;
 }
 
 void Updater::onNetworkReplyFinished(QNetworkReply * reply)
@@ -235,6 +232,9 @@ void Updater::onNetworkReplyFinished(QNetworkReply * reply)
     Logger::note("******* Full reply contents ******\n");
     Logger::note(reply->readAll());
     Logger::note(QString("******** HTTP Status: %1").arg(reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt()));
+    // We either create an empty local file or 'touch' the existing one to prevent a systematic update on next startups
+    // Instead, usual delay will occur before next try
+    touchFile(localFilename(reply->url().toString()));
   }
   _pendingReplies.remove(reply);
   if (_pendingReplies.isEmpty()) {
@@ -279,8 +279,10 @@ QByteArray Updater::cimgzDecompress(const QByteArray & array)
     Logger::warning("Updater::cimgzDecompress(): Error creating " + tmpZ.fileName());
     return QByteArray();
   }
-  tmpZ.write(array);
-  tmpZ.flush();
+  if (!writeAll(array, tmpZ)) {
+    Logger::warning("Updater::cimgzDecompress(): Error writing temporary " + tmpZ.fileName());
+    return QByteArray();
+  }
   tmpZ.close();
   cimg_library::CImg<unsigned char> buffer;
   try {
