@@ -52,7 +52,7 @@
 */
 
 #ifndef gmic_version
-#define gmic_version 295
+#define gmic_version 301
 
 #ifndef gmic_pixel_type
 #define gmic_pixel_type float
@@ -196,35 +196,47 @@ namespace cimg_library {
 
 #ifdef cimg_use_abort
 inline bool *gmic_abort_ptr(bool *const p_is_abort);
-#define cimg_abort_init bool *const gmic_is_abort = ::gmic_abort_ptr(0)
+#define cimg_abort_init bool *const gmic_is_abort = ::gmic_abort_ptr(0); cimg::unused(gmic_is_abort)
 #define cimg_abort_test if (*gmic_is_abort) throw CImgAbortException()
 #endif
 
 template<typename T>
-inline double gmic_mp_run(char *const str,
-                          void *const p_list, const T& pixel_type);
-#define cimg_mp_func_run(str) \
-  return ::gmic_mp_run(str,&mp.listout,(T)0)
+inline double gmic_mp_dollar(const char *const str,
+                             void *const p_list, const T& pixel_type);
+#define cimg_mp_operator_dollar(str) \
+  ::gmic_mp_dollar(str,&imglist,(T)0)
 
 template<typename Ts, typename T>
-inline double gmic_mp_get(Ts *const ptr, const unsigned int siz, const bool to_numbers, const char *const str,
+inline double gmic_mp_get(Ts *const ptr, const unsigned int siz, const bool to_string, const char *const str,
                           void *const p_list, const T& pixel_type);
-#define cimg_mp_func_get(ptr,siz,to_numbers,str) \
-  return ::gmic_mp_get(ptr,siz,to_numbers,str,&mp.listout,(T)0)
+#define cimg_mp_func_get(ptr,siz,to_string,str) \
+  return ::gmic_mp_get(ptr,siz,to_string,str,&mp.imglist,(T)0)
 
 template<typename Ts, typename T>
-inline double gmic_mp_store(const Ts *const ptr,
-                            const unsigned int w, const unsigned int h, const unsigned int d, const unsigned int s,
-                            const bool is_compressed, const char *const str,
-                            void *const p_list, const T& pixel_type);
-#define cimg_mp_func_store(ptr,w,h,d,s,is_compressed,str) \
-  return ::gmic_mp_store(ptr,w,h,d,s,is_compressed,str,&mp.listout,(T)0)
+inline double gmic_mp_set(Ts *const ptr, const unsigned int siz, const char *const str,
+                          void *const p_list, const T& pixel_type);
+#define cimg_mp_func_set(ptr,siz,str) \
+  return ::gmic_mp_set(ptr,siz,str,&mp.imglist,(T)0)
 
 template<typename T, typename Ts>
 inline double gmic_mp_name(const unsigned int ind, Ts *const out_str, const unsigned int siz,
                            void *const p_list, const T& pixel_type);
 #define cimg_mp_func_name(ind,out_str,siz) \
-  return ::gmic_mp_name(ind,out_str,siz,&mp.listout,(T)0)
+  return ::gmic_mp_name(ind,out_str,siz,&mp.imglist,(T)0)
+
+template<typename T>
+inline double gmic_mp_run(char *const str,
+                          void *const p_list, const T& pixel_type);
+#define cimg_mp_func_run(str) \
+  return ::gmic_mp_run(str,&mp.imglist,(T)0)
+
+template<typename Ts, typename T>
+inline double gmic_mp_store(const Ts *const ptr, const unsigned int siz,
+                            const unsigned int w, const unsigned int h, const unsigned int d, const unsigned int s,
+                            const bool is_compressed, const char *const str,
+                            void *const p_list, const T& pixel_type);
+#define cimg_mp_func_store(ptr,siz,w,h,d,s,is_compressed,str) \
+  return ::gmic_mp_store(ptr,siz,w,h,d,s,is_compressed,str,&mp.imglist,(T)0)
 
 #ifndef cimg_display
 #define cimg_display 0
@@ -298,19 +310,25 @@ struct gmic {
   template<typename T>
   static bool search_sorted(const char *const str, const T& list, const unsigned int length, unsigned int &out_ind);
   template<typename T>
-  static double mp_run(char *const str,
+  static double mp_dollar(const char *const str,
+                          void *const p_list, const T& pixel_type);
+  template<typename Ts, typename T>
+  static double mp_get(Ts *const ptr, const unsigned int siz, const bool to_string, const char *const str,
                        void *const p_list, const T& pixel_type);
   template<typename Ts, typename T>
-  static double mp_get(Ts *const ptr, const unsigned int siz, const bool to_numbers, const char *const str,
+  static double mp_set(Ts *const ptr, const unsigned int siz, const char *const str,
                        void *const p_list, const T& pixel_type);
-  template<typename Ts, typename T>
-  static double mp_store(const Ts *const ptr,
-                         const unsigned int w, const unsigned int h, const unsigned int d, const unsigned int s,
-                         const bool is_compressed, const char *const str,
-                         void *const p_list, const T& pixel_type);
   template<typename T, typename Ts>
   static double mp_name(const unsigned int ind, Ts *const out_str, const unsigned int siz,
                         void *const p_list, const T& pixel_type);
+  template<typename T>
+  static double mp_run(char *const str,
+                       void *const p_list, const T& pixel_type);
+  template<typename Ts, typename T>
+  static double mp_store(const Ts *const ptr, const unsigned int siz,
+                         const unsigned int w, const unsigned int h, const unsigned int d, const unsigned int s,
+                         const bool is_compressed, const char *const str,
+                         void *const p_list, const T& pixel_type);
   static bool get_debug_info(const char *const s, unsigned int &line_number, unsigned int &file_number);
   static int _levenshtein(const char *const s, const char *const t,
                           gmic_image<int>& d, const int i, const int j);
@@ -333,16 +351,18 @@ struct gmic {
   gmic_image<char> get_variable(const char *const name,
                                 const unsigned int *const variables_sizes=0,
                                 const gmic_list<char> *const images_names=0) const;
-  const char *set_variable(const char *const name, const char *const value,
-                           const char operation='=',
+  const char *set_variable(const char *const name, const char operation='=',
+                           const char *const value=0, const double *const pvalue=0,
                            const unsigned int *const variables_sizes=0);
   const char *set_variable(const char *const name, const gmic_image<unsigned char>& value,
                            const unsigned int *const variables_sizes=0);
 
   gmic& add_commands(const char *const data_commands, const char *const commands_file=0,
+                     const bool add_debug_info=false,
                      unsigned int *count_new=0, unsigned int *count_replaced=0,
                      bool *const is_entrypoint=0);
   gmic& add_commands(std::FILE *const file, const char *const filename=0,
+                     const bool add_debug_info=false,
                      unsigned int *count_new=0, unsigned int *count_replaced=0,
                      bool *const is_entrypoint=0);
 
@@ -505,24 +525,26 @@ struct gmic_exception {
   }
 };
 
+inline bool *gmic_abort_ptr(bool *const p_is_abort) {
+  return gmic::abort_ptr(p_is_abort);
+}
+
 template<typename T>
-inline double gmic_mp_run(char *const str,
-                          void *const p_list, const T& pixel_type) {
-  return gmic::mp_run(str,p_list,pixel_type);
+inline double gmic_mp_dollar(const char *const str,
+                             void *const p_list, const T& pixel_type) {
+  return gmic::mp_dollar(str,p_list,pixel_type);
 }
 
 template<typename Ts, typename T>
-inline double gmic_mp_get(Ts *const ptr, const unsigned int siz, const bool to_numbers, const char *const str,
+inline double gmic_mp_get(Ts *const ptr, const unsigned int siz, const bool to_string, const char *const str,
                           void *const p_list, const T& pixel_type) {
-  return gmic::mp_get(ptr,siz,to_numbers,str,p_list,pixel_type);
+  return gmic::mp_get(ptr,siz,to_string,str,p_list,pixel_type);
 }
 
 template<typename Ts, typename T>
-inline double gmic_mp_store(const Ts *const ptr,
-                            const unsigned int w, const unsigned int h, const unsigned int d, const unsigned int s,
-                            const bool is_compressed, const char *const str,
-                            void *const p_list, const T& pixel_type) {
-  return gmic::mp_store(ptr,w,h,d,s,is_compressed,str,p_list,pixel_type);
+inline double gmic_mp_set(Ts *const ptr, const unsigned int siz, const char *const str,
+                          void *const p_list, const T& pixel_type) {
+  return gmic::mp_set(ptr,siz,str,p_list,pixel_type);
 }
 
 template<typename T, typename Ts>
@@ -531,7 +553,19 @@ inline double gmic_mp_name(const unsigned int ind, Ts *const out_str, const unsi
   return gmic::mp_name(ind,out_str,siz,p_list,pixel_type);
 }
 
-inline bool *gmic_abort_ptr(bool *const p_is_abort) { return gmic::abort_ptr(p_is_abort); }
+template<typename T>
+inline double gmic_mp_run(char *const str,
+                          void *const p_list, const T& pixel_type) {
+  return gmic::mp_run(str,p_list,pixel_type);
+}
+
+template<typename Ts, typename T>
+inline double gmic_mp_store(const Ts *const ptr, const unsigned int siz,
+                            const unsigned int w, const unsigned int h, const unsigned int d, const unsigned int s,
+                            const bool is_compressed, const char *const str,
+                            void *const p_list, const T& pixel_type) {
+  return gmic::mp_store(ptr,siz,w,h,d,s,is_compressed,str,p_list,pixel_type);
+}
 
 #endif // #ifndef gmic_version
 
